@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2007,2008 daniel g. siegel <dgsiegel@gmail.com>
+ * Copyright © 2007,2008 daniel g. siegel <dgsiegel@gmail.com>
  *
  * Licensed under the GNU General Public License Version 2
  *
@@ -21,8 +21,10 @@
 #define __CHEESE_WINDOW_H__
 
 #include <gtk/gtk.h>
+#include "cheese-dbus.h"
 
 
-void cheese_window_init (char *hal_dev_udi);
+void cheese_window_init (char *hal_dev_udi, CheeseDbus *dbus_server, gboolean startup_in_wide_mode);
+void cheese_window_bring_to_front (gpointer data);
 
 #endif /* __CHEESE_WINDOW_H__ */
